# Utilities for simple needs



## Auxiliary Functions
There are simple functions that are overloaded to take inputs and perform repetitive tasks that usually take a few lines to write

#### Images
`show`, `inspect`, `Glob`, `read`, `resize`, `rotate`

#### Files and Paths
`stem`, `Glob`, `parent`, `name`, `fname`,


`makedir`, `zip_files`, `unzip_file`,   


`find`, `extn`,  


`readlines`, `writelines`

#### Lists
`L`, `flatten`

#### Dump and load python objects
`loaddill`,`dumpdill`

#### Misc 
`Tqdm`, `Timer`, `randint`, `Logger`

#### Sets
`unique`, `diff`, `choose`, `common`

#### Pytorch Modules
`Reshape` and `Permute` (`nn.Modules`)

#### Report as Pytorch Lightning Callback
`LightningReport`

and many more to come... 

## Install
`pip install torch_snippets`

## Usage
```python
import pytorch_snippets
dir(pytorch_snippets)
```

